@@ -145,7 +145,7 @@ class SciNoteClient(object):
 
         while r_json["links"]["next"]:
             r = self.get(r_json["links"]["next"])
-            r_json.extend(r.json())
+            r_json.update(r.json())
 
         teams_dict = {
             team["attributes"]["name"].replace("🟢 ", "")
@@ -165,7 +165,7 @@ class SciNoteClient(object):
 
         while r_json["links"]["next"]:
             r = self.get(r_json["links"]["next"])
-            r_json.extend(r.json())
+            r_json.update(r.json())
 
         inventories_dict = {
             inventory["attributes"]["name"]: inventory["id"]
@@ -223,7 +223,7 @@ class SciNoteClient(object):
 
         while r_json["links"]["next"]:
             r = self.get(r_json["links"]["next"])
-            r_json.extend(r.json())
+            r_json.update(r.json())
 
         options_dict = {
             option["attributes"]["data"]: option["id"] for option in r_json["data"]
@@ -429,7 +429,7 @@ class SciNoteClient(object):
 
         while r_json["links"]["next"]:
             r = self.get(r_json["links"]["next"])
-            r_json.extend(r.json())
+            r_json.update(r.json())
 
         folders_dict = {
             folder["attributes"]["name"]: folder["id"] for folder in r_json["data"]
